.noGenerics <- TRUE

.onLoad <- function(libname, pkgname)
{
  cat("\nHow to use CEM? Type vignette(\"cem\")\n")
# library.dynam("cem", pkgname, libname) 
}

